{% load i18n %}

<div class="markdown-widget-wrapper max-w-4xl">
    <textarea name="{{ widget.name }}" id="markdown-{{ widget.name }}"{% if widget.value != None %}>{{ widget.value }}</textarea>{% else %}></textarea>{% endif %}
</div>

