from django.apps import AppConfig


class UnfoldMarkdownConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "unfold_markdown"
    verbose_name = "Unfold Markdown Widget"

